@@ -110,10 +110,7 @@ class TestTxrmToImageSimple(unittest.TestCase):
         offset = [3., -2.]
         # Multiplier of 1.e3 required as units from xrm files are micrometres and the output should be in nanometres
         expected_centre = ((22.5 + offset[0]) * pixel_size * 1.e3, (20. + offset[1]) * pixel_size * 1.e3)
-
         
-        image_divider = MagicMock()
-        txrm_converter = TxrmToImage()
         ole = MagicMock()
         ole.exists.return_value = True
         mocked_extractor.extract_multiple_exposure_times.return_value = exposure_times
@@ -189,35 +186,36 @@ class TestTxrmToImageSimple(unittest.TestCase):
         assert_array_equal(ref, custom_reference[0])
 
 
-base_path = Path("/dls/science/groups/das/ExampleData/B24_test_data/data/2019/cm98765-1")
-raw_path = base_path / "raw"
+visit_path = Path("/dls/science/groups/das/ExampleData/B24_test_data/data/2019/cm98765-1")
+raw_path = visit_path / "raw"
 xm10_path = raw_path / "XMv10"
 xm13_path = raw_path / "XMv13"
 
 test_files = [
     (xm13_path / 'Xray_mosaic_v13.xrm', ),
     (xm13_path / 'Xray_mosaic_v13_interrupt.xrm', ),
+    (xm13_path / 'Xray_mosaic_7x7_v13.xrm', ),
     (xm13_path / 'Xray_single_v13.xrm', ),
     (xm13_path / 'tomo_v13_full.txrm', ),
     (xm13_path / 'tomo_v13_full_noref.txrm', ),
     (xm13_path / 'tomo_v13_interrupt.txrm', ),
     (xm13_path / 'VLM_mosaic_v13.xrm', ),
     (xm13_path / 'VLM_mosaic_v13_interrupt.xrm', ),
+    (xm13_path / 'VLM_grid_mosaic_large_v13.xrm', ),
     (xm10_path / '12_Tomo_F4D_Area1_noref.txrm', ),
     (xm10_path / 'VLM_mosaic.xrm', ),
     (xm10_path / 'test_tomo2_e3C_full.txrm', ),
     (xm10_path / 'Xray_mosaic_F5A.xrm', ),
-]
+    ]
 
-
-@unittest.skipUnless(base_path.exists(), "dls paths cannot be accessed")
+@unittest.skipUnless(visit_path.exists(), "dls paths cannot be accessed")
 class TestTxrmToImageWithFiles(unittest.TestCase):
 
     @classmethod
     def setUpClass(cls):
-        cls.base_path = base_path
+        cls.visit_path = visit_path
         cls.raw_path = raw_path
-        cls.processed_path = cls.base_path / "processed"
+        cls.processed_path = cls.visit_path / "processed"
         if cls.processed_path.exists():
             cleanup_timeout = 40
             # rmtree is asynchronous, so a wait may be required:
@@ -227,7 +225,7 @@ class TestTxrmToImageWithFiles(unittest.TestCase):
                 sleep(1)
 
     def setUp(self):
-        self.processed_path.mkdir()
+        self.processed_path.mkdir(exist_ok=True)
         self.assertTrue(self.processed_path.exists(), msg="Processed folder not correctly created")
     
     def tearDown(self):
